import setuptools

setuptools.setup(
    name='ohsgpgn',
    version='0.0.39',
    author='OhYoungJooung',
    author_email='wnapdlf05@gmail.com',
    packages=[''],
    #packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    url='http://pypi.python.org/pypi/ohsgpgn/',
    license='LICENSE.txt',
    description='oh Simple good password generator(ohsgpgn)',
    long_description=open('README.txt').read(),
    #install_requires=[
    #],
    python_requires='>=3.6',
)
